@@ -17,20 +17,19 @@
 # under the License.
 #
 
-require 5.6.0;
+use 5.10.0;
 use strict;
 use warnings;
 
 use Thrift;
+use Thrift::Exception;
 
 #
 # Transport exceptions
 #
-package TTransportException;
-{
-  $TTransportException::VERSION = '0.9.0';
-}
+package Thrift::TTransportException;
 use base('Thrift::TException');
+use version 0.77; our $VERSION = version->declare("$Thrift::VERSION");
 
 use constant UNKNOWN      => 0;
 use constant NOT_OPEN     => 1;
@@ -38,7 +37,7 @@ use constant ALREADY_OPEN => 2;
 use constant TIMED_OUT    => 3;
 use constant END_OF_FILE  => 4;
 
-sub new{
+sub new {
     my $classname = shift;
     my $self      = $classname->SUPER::new(@_);
 
@@ -46,9 +45,7 @@ sub new{
 }
 
 package Thrift::Transport;
-{
-  $Thrift::Transport::VERSION = '0.9.0';
-}
+use version 0.77; our $VERSION = version->declare("$Thrift::VERSION");
 
 #
 # Whether this transport is open.
@@ -87,8 +84,7 @@ sub close
 #
 sub read
 {
-    my ($len);
-    die("abstract");
+    die "abstract";
 }
 
 #
@@ -120,7 +116,6 @@ sub readAll
 #
 sub write
 {
-    my ($buf);
     die "abstract";
 }
 
@@ -136,9 +131,7 @@ sub flush {}
 # TransportFactory creates transport objects from transports
 #
 package Thrift::TransportFactory;
-{
-  $Thrift::TransportFactory::VERSION = '0.9.0';
-}
+use version 0.77; our $VERSION = version->declare("$Thrift::VERSION");
 
 sub new {
     my $classname = shift;
@@ -165,9 +158,7 @@ sub getTransport
 #  ServerTransport base class module
 #
 package Thrift::ServerTransport;
-{
-  $Thrift::ServerTransport::VERSION = '0.9.0';
-}
+use version 0.77; our $VERSION = version->declare("$Thrift::VERSION");
 
 sub listen
 {
